# My setting for the Great Game

It should be evident that all the key ideas in The Great Game project would be applicable to games set in the historic past of our world, to games set in its present, or to games set in some imagined or forecast future; the ideas are intended to be, and I believe are, largely independent of setting.

Nevertheless I feel the need for a concrete setting to ground the development of ideas. I've chosen deliberately not to place that setting in the real world; although it's broadly based on cultures from the late bronze age/early iron age mediterrainian. 

So, phase one of The Great Game takes place in the triangle between Hans'hua, Sinhua, and Tchahua &mdash; the territory covered in the narratives [Merchant](http://www.journeyman.cc/~simon/tmp/merchant.pdf). The narrative from Merchant will form the basis for characters within the game, who will broadly have the skills, objectives and interests that they do in the narrative, but the events of the narrative won't be canon, partly because actions by the player may intervene and partly because in a dynamic game actions won't play out the same every time anyway. 

It will also take place in that time period, so, essentially, at the beginning of the Merchants' War; this document lays out the strategic position in the game world at that point. 

For clarity, the Merchants' War is a war started by mercantile interests in Sinhua, one of the cities which are totally bypassed by the new circumcontinental trade routes, with the objective of capturing Hans'hua (which controls the Caravan Road), Tchahua (the only port on the coast capable of handling the new ships), and Silver Hold, the place in the far west where silver, copper and tin are mined, and a great deal of coinage produced. If the Merchants' War succeeds, Sinhua will become by far the most powerful city on the coast; but it's a hugely expensive gamble.

The prime mover of the war is a banker in Sinhua named Nikkei. He has a number of co-conspirators, definitely including Fannish, an ariston who has been engaged in civil war against the Tyrranos of Sinhua, Kildor, who has no actual legitimate claim to rule but is in a very abusive rape/marriage with Xinta, who is 

Similarly I'll probably include at least some characters from other unfinished narratives set in the same world. The events of the game happen after the events in [The Rite of Spring](https://www.journeyman.cc/~simon/bookshelf/hyper/mgi/), so some version of those events will be canon, but:

1. A revised version, because I'm now not at all happy with central themes in that plot;
2. The part of the world in which phase one happens is a long way from The Great Place, the player can't go there, and although the player may meet people who have been there and know the lore, it isn't particularly relevant to anything they will do.

All the lore in the [background documents](https://www.journeyman.cc/~simon/bookshelf/hyper/mgi/Background.html) is canon, however, unless explicitly revised.

The map of the Cities of the Coast is revised, however, and as that covers the area where the game is set, this will be covered below.

# Strategic situation

City states with feudal culture, generally ruled by dictators known as tyrranos. Succession generally chaotic (there's some theory of primogeniture, but in practice there's usually a power-struggle). Formerly there was a feudal military class, the aristons, but although aristons continue to be wealthy landowners, wars are now increasingly fought by mercenary companies.

## Significant Cults

There are two main cult families which are widespread throughout the world:

1. The House of the Mother is a matrideic, earth mother worshipping, sex-positive, generally pacific cult, emphasising mind-body integration and oneness with the earth. This cult practices (among other things) sacramental sex acts.
2. The House of the Dragon is a patrideic, sky-god worshipping, sex-negative, generally warlike cult, emphasising mind-body duality and an afterlife available only to warriors. This cult practices (among other things) live sacrifice &mdash; specifically including human sacrifice &mdash; to dragons, which are seen as avatars of the god.

The Great Place has a much more complicated religious system [documented here](https://www.journeyman.cc/~simon/bookshelf/hyper/mgi/Religion.html) but fundamentally even that is an elaboration on the two main cults described above. In any case the Great Place is outside the playable area for at least this phase of the game, so although there's a great deal of lore about it we don't need too much detail.

### The Incarnator

The significant difference about religion in The Great Place is that the incarnation is 'real', in the sense that there is a unique thing, apparently (and as far as it knows) immortal, which has intelligence and agency, which can inhabit the minds of people and of dragons (but not of other creatures), and which has as a matter of practice one long-term symbiotic relationship with a person (or dragon, but usually person) at a time.

The incarnator is of somewhat superhuman intelligence, has an impressive memory, is lonely, and is essentially benevolent; but does not see itself as infallible.

It is my intention that somewhere down the arc of the Great Game, the player may become host to the incarnator, and therefore gain the powers listed below. However, exactly how this works has to remain a secret, even in a project which is open source!

#### History

The incarnator has for several hundred years manifested in a series of people in The Great Place, essentially as a benevolent dictator, trying (and very largely succeeding) to build a stable, prosperous, peaceful society; but, following events in The Rite of Spring, about twenty years before the setting of the game, the incarnator has lost confidence in this project, and is no longer sure that its intervention is beneficial.

Consequently, the current incarnation (who is Aonan a'Aonach, but this is not known to anyone outside her immediate household) has retired to a hidden house on the outside slope of the Rim, slightly south of the Sunset Pass. There are rumours within the Great Place that the House of the Last Incarnation exists, and that either the incarnation, or the person who was the last incarnation, is still alive and living there, but its location is (at least during the first phase of the Great Game) unknown.

It's my intention that it's a location which players at least in principal can visit, as visitors, even if they do not become the incarnation, at some stage in the arc; but I haven't really thought through how this works and it isn't in phase one.

#### Special powers

The incarnation is the word used to describe the person currently in symbiotic relationship with the incarnator. The incarnation gains considerable powers as a result of the relationship; she can temporarily inhabit other people, see through their eyes, listen through their ears, and influence their actions, without them knowing. She rarely does this, seeing it as generally unethical, but she can. She can influence the perceptions of people in her presence, and she does this normally to influence their perception of her &mdash; habitually appearing to the priests as a figure of light, normally of a gender to which the other person is sexually attracted; but equally, able to pass anywhere in any disguise without actually having even to change clothes.

The incarnator/incarnation can also make (polite) requests of dragons to do things, and, when requested, dragons can (among other things) speak to people, and large dragons can allow people to ride them. Whether dragons can do these things when not requested by the incarnation is unknown; but in practice they don't. Being spoken to, or given a lift by, a dragon is very rare, and serious people are skeptical about whether it's even possible, but dragon riding does feature in popular songs and stories.

#### Belief

The consensus belief of most people within the Great Place &mdash; and by some, mainly intellectuals, outside &mdash; is essentially Unitarian: that there is (exactly one) god, that the incarnator is that god, and that all the cults worship different aspects of the same god. The incarnator does not share this belief, and, in particular, increasingly finds the beliefs of the Dragon Cult impossible to either ameliorate or integrate into the syncretic faith it has been trying to build.

## General History

Prior to the development of steel weapons in the north, there was a fairly stable situation on the continent, with the southern littoral (the game area we're currently considering) being sparsely populated by an essentially neolithic people who cleared a small amount of forest and farmed in some places but were primarily hunter gatherers. These people rarely engaged in conflict, and had no military culture. West of this, the Western Clans &mdash; who had access to metals &mdash; had a more bronze age civilisation,with something of a hero culture and occasional hero-on-hero fights, but these rarely led to deaths and very rarely to more widespread violence.

The Great Place was inhabited by a similar population to the southern littoral, but because the surrounding mountains make a pretty formidable barrier, the two populations were isolated from one another.

### The First Incarnation

Sometime a long time back &mdash; of the order of a thousand years, but more work needed &mdash; the incarnation first appeared in the Great Place, and established its home on the High Place; a settlement already existed on the site of the City At Her Gates, and this has developed over time. Gradually, settled rule essentially driven by the incarnator was established over all the lands within the Rim. The incarnator had hoped that this system would expand outwards, but has lost confidence in it.

### The Steel Age

Sometime before 500 years back &mdash; again, I need to do work to establish chronology &mdash; high quality steel making was developed in the north of the world, leading to both much better tools and much better weapons. I know almost nothing about the internal history of the far north &mdash; there are city states there and there have been wars between them, but I don't have even the vaguest outline.

Within quite a short time of the start of the steel age, steel weapons began to find their way into the hands of the steppe tribes. This was because steppe warriors hired themselves out as mercenaries to northern cities, and thus picked up their military technology. The steel weapons greatly increased the bloodiness of inter-tribal feuding on the steppe, and led to three important consequences, all roughly around the 500 years ago time period.

#### Kiar

Kiar was a matrideic priestess within a less well armed, less warlike, horse-breeding tribe on the southern steppe &mdash; possibly the same tribe, certainly a closely related tribe, as that which became the Wild Herd &mdash; led her people on what was essentially a fighting retreat over the Sunset Pass into the Great Place, where, on the direction of the incarnation of the time, she was allowed in; her people settled in an area of previously sparsely settled land in the west of the Great Place, where they continue to be a slightly separate community, but are generally accepted as being citizens. 

#### The Retreat of the Wild Herd

A more radically matrideic and feminist group of mainly women from a less well armed, less warlike, horse-breeding tribe on the southern steppe retreated into a marshland which forms against the foot of the northern slope of the plateau, where water off the steppe, having originally fallen mostly on the western mountains, pools before seeping underground to form the subterranean rivers under the plateau and emerge on the littoral. This marshland is extremely difficult to fight in and to move fast in, and, partly by developing skills in archery, they were able to make it into a natural fortress.

They have, over the intervening period, developed a variant of the common language of the steppe which has much the same grammar as everyone else's but such an altered pronunciation that it's impenetrable; they've also selectively bred themselves towards one particular ideal physical type, and have a practice of keeping very few adult males - a male to female ratio f fewer than 1/50. The males they do keep are those considered most likely to father the preferred physical type, and they are kept exclusively for breeding. They are generally kept somewhat sedated, and supervised by armed female warriors.

Boy children who are not selected as breeding studs are castrated and sold into slavery as eunuchs; adult males who were selected but don't father the desired children are also sold into slavery but not normally castrated, and this is Choiremheadh's story.  

#### The Invasion of the Aristons

A hoard of mostly male, mounted, warlike steel-armed northern ex-mercenaries made the crossing south across the plateau in winter, and arrived in the southern littoral, initially following what has since become the caravan road south east across the Sind at the Black Ford to the valley of the Koan, where they started to conquer land and build. Within a couple of generations they'd spread out across the littoral as far as the Rim &mdash; which they couldn't cross &mdash; in the east, and the border with the Western Clans &mdash; where they met their match, militarily &mdash; in the west.

Being northerners, the aristons, as they now called themselves, were slightly paler skinned although of broadly the same ethnic group as the indigenous people of the littoral, and they spoke a language which was not utterly different, so that the two populations could more or less understand one another. The current language of the coast is a mix of indigenous and northern elements.

### The Founding of Cities

All the major cities of the coast, and Hans'hua, were founded within two generations of the invasion of the aristons. Of them, Koantuan was the first, and for a long time the most powerful.

## Topography

The geology is limestone. There is a high limestone plateau to the north, which, because it is wide, arid and fissured with a complex pattern of clints and grykes, is extremely hard to cross except along the caravan road, towards the north east of the playable area, which is controlled by Hans'hua. All of the major rivers of the littoral emerge from under the high plateau, and have carved deep, steep sided valleys through the limestone. These valleys are sheltered and fertile, and within historical record were all forested; in the current period, however, all have to one degree or another been cleared to make agricultural land.

Crossing from one river valley to another means climbing to peninsulas of limestone extending south from the plateau, and these peninsulas are also generally flat topped and fairly arid, although there is a sort of maquis-like scrub which grows on most of it.

### Agriculture and Fisheries

Clearance of forest is most notable in the Koan Valley (which produces wheat and other cereals, but also cattle and horses) and Sind (wheat and other cereals, but also vineyards) valleys. The Tcha Valley, at the western end of the playable area, is still about 50% forested, partly because it has until recently been poorer and less populated, partly because the silk industry required mulberry orchards. 

Chestnut trees are common in woodlands across the region, and the nuts are harvested and ground into flour as a staple food; many species of fruiting tree are present and their fruits are also harvested. In some places there are intentionally planted and cultivated orchards, but 'wild' fruiting trees in the woodlands are also tended for food production.

All the rivers produce fish, and are fished.

Tchahua and Quanhua were both originally fishing villages; both still have significant fishing fleets, and dried and smoked fish are exports from both. There is also a fishing village at the mouth of the Koan, and there are probably others along the coast between the Tcha and the Koan, but I don't yet have details of these.

#### Minerology and metals

Because the geology is limestone, there are no significant metal deposits in the whole of this area. In the extreme east, there are deposits in the mountains of The Rim which could be mined, but the presence of dragons makes this impracticable.

Copper, bronze, silver, and iron are imported from Andale in the lands of the Western Clans, but are expensive &mdash; bronze and silver are imported primarily as coinage. Gold and bronze are imported from the Great Place, again primarily as coinage. Via the House of the Mother, coinage production is co-ordinated between Andale and the Great Place to maintain ratios of value by weight of eight bronze to one silver, and eight silver to one gold. Iron is valued above bronze, but below silver.

Steel comes only from the far north. Nowhere in the south has either the quality ores or the technology to make it. Furthermore, the skills to work steel into high quality tools and weapons are much higher in the far north than in the south, so all good tools and weapons are imported. Prior to the great ships steel and steel artefacts came only by the Caravan Road, which meant the quantity was limited and the price very high &mdash; almost as high as gold.

With the great ships able to carry more weight of cargo, prices are falling, but steel tools and weapons are still worth more than their weight in silver. Skilled, well-established craftsmen have few of them and they're taken great care of.

##### Military equipment and tactics

Many soldiers and mercenaries still do not have steel weapons; iron is still common and bronze is still in use. The Red Company is the first mercenary company to routinely issue steel weapons, but even so rank-and-file soldiers will only have a steel spearhead. Officers will also have steel swords. Steel daggers exist within the company, but most daggers are not yet steel.

Steel plate armour is known but exceptionally rare, limited to only the richest individuals on the battlefield; lamellar chest armour with boiled leather shoulder protection and kilts made of straps of boiled leather is what is worn by most heavy troops, with leather or (brigandine-like) fabric armour being used by light troops. Forearm and shin protection is common, normally of boiled leather, sometimes of bronze. Both leather and fabric armour may be reinforced with bronze plates.

Chain mail is known but not common &mdash; it can only be made of steel, which is hugely expensive, while lamellar armour is typically bronze. 

The Western Clans use longbow archery in warfare, so longbows are known, but there are no significant military archery companies in the game area at this point: only a couple of generations back, armies consisted of ill-trained and very lightly armed feudal levies on foot led by armoured aristons on horseback, with small companies of (mainly ariston) cavalry; then mercenary companies started to emerge which were more permanent and better trained; and then the Red Company emerged as a heavy infantry company with the discipline and (phalanx-like) tactics to defeat even heavy and concentrated cavalry.

Now, other armed groups are emulating Red Company tactics, but with varying success.

##### Other consequences of geography

Because the geology is entirely limestone, there are also no good clays, and no glassmaking sands. Ceramics and glass are also imported. The best ceramics and all glassware comes from the far north, and was until recently extremely expensive. The Great Place produces reasonably good ceramics which have been imported by coastal shipping and is reasonably inexpensive; the Western Clans also produce ceramics which are available but of a lower quality.

## Major transport routes

The Tcha is the river that runs under the plateau from Hans'hua, and from which the deep wells in Hans'hua raise water, but this is not a fact generally known. It emerges from under the plateau as a pool beside which Hans'hua maintains a garrisoned tower. A little way (less than half a day) south of the South Tower is the South Inn, which is southern limit of the territory defended by Hans'hua. However it's navigable even by light river barges for only part of its length.

Barges are pulled upstream from Tchahua to Sinhua by horses or oxen, and drift downstream on the current. Some silks are still carried upstream to the market in Sinhua, but this is no longer a major trade; northern trade goods which had arrived in Tchahua from the north in the great ships now go upstream to the markets in Sinhua, where they're lowering the prices that caravan traders can get for similar goods. Finally, Tchahua sells timber upstream to Sinhua, mainly from the Tcha Valley, some imported by coastal ship from the Gor. Downstream, the trade is cereals, wines and spirits, and jewellery. Much of this is shipped on in coastal ships to Huandun, Quanhua and the Great Place to the east, and to the Gor to the west.

The Sind river, which is navigable by flat bottomed boats all the way up to Sinhua, is a tributary to the Tcha, but joins it less than half a day's ride above Tchahua.

The Koan River is navigable between Koantuan and Huandun by river barge, and from Huandun to the sea by coastal shipping. There's not a lot of traffic on the river, however, because these cities now largely supply foodstuffs, with which the other cities of the south are well provided.

The Quan River in the far east of the area might in principle be navigable for part of its length, but dragons make this impractical. Similarly, only the extreme west of the Quan valley is cleared for farmland, because it isn't practicable for people to work in the open in daytime in much of the valley.

### Caravan Road

The Caravan Road comes from the far north of the continent, across the steppe, to Hans'hua's North Inn, which is situated on fertile land on the edge of the steppe just north of the main plateau. However, the player cannot travel north of the North Inn, at least in the initial phase of game development, so this is the edge of the playable world. There's a garrisoned (by Hans'hua) fortified tower adjacent to the North Inn, defending it. In former times Hans'hua had several garrisoned towers along the route north across the steppe, but these are no longer garrisoned (and are probably ruinous, but they're outside the game area so it doesn't matter).

Southward from the North Inn it's at least two days travel by fast horse along the Caravan Road across the plateau to Hans'hua itself; south of Hans'hua it's again at least two days travel by fast horse to the South Inn. There are shelters along the route where travellers can camp and shelter from the sun (travel during daytime in summer is not advisable, due to glare and risk of heatstroke), but these shelters have no water &mdash; travellers have to carry water for themselves and for their animals. 

Water is obtainable in Hans'hua from the Company of Waters, who maintain the wind-driven pumps, but it's expensive.

From the South Inn the Caravan Road runs east over a lower, scrubby plateau to the Black Ford across the Sind river. There's an island in the middle of the ford on which there's a garrisoned tower and toll point; the tower was originally built by Koantuan but has changed hands several times and at the beginning of the game is in the hands of Sinhua. From the Black ford, one branch of the Caravan Road runs south-east across a further scrubby plateau to Koantuan; the other, north-east up the valley to Sinhua.

The river is not fordable at the Black Ford in winter, or in early spring; it is not easily fordable on foot at any time of year. Camels will manage it with reasonable ease in summer and autumn, horses may have to swim a bit but will get through. Wagons basically won't, but the caravans don't use wagons anyway.

#### Other roads

There's a road down the east side of the Tcha Valley, but it's pretty minor. It crosses the Sind at a ferry that doesn't have capacity for caravans. There's also a road down the west side, from a ford at the South Inn to the bridge at Tchahua. This carries a lot of the food that feeds Hans'hua, from farms towards the north end of the Tcha Valley, and this northern section is maintained for wagon transport. Further south, though, the road is less good.

Prior to the great ships, Tchahua's silk trade went up the Sind river to Sinhua and joined the caravans there. There is a road up the east bank of the Sind, because there's a tow path for horses or oxen pulling the river barges, but it isn't a good road until north of the Black Ford. There's a road that leads west from Tchahua towards the Gor border, but for the purposes of the game that border is closed.

A road leads over the plateau from Huandun to Quanhua, but it is somewhat exposed to dragons and thus best travelled at night.

There's a road of sorts up the valley of the Quan (usually called 'the Dragon's Run') which runs through woodland for safety, from Quanhua all the way up to the ancient Dragon Cult centre at Quanjun, on the very edge of the high plateau. From Quanjun it's possible in emergency (but extremely dangerous) to continue north along the line where the plateau meets the mountains of the Rim to the steppe, and thus onwards towards the Sunset Pass into the Great Place, but there's very little water and lots of dragons so... it's not often used (and you can't use it in the game).

There's also a minor road from Koantuan up to Quanjun (which is, in effect the main road to Quanjun), but except at festival times it's not much used.

### The Great Ships

The great ships, capable of circumnavigating the continent, are an extremely new development in the time of the Merchants' War. On page 132 of the latest draft of Merchant, we learn there are as yet only six of them. They are much faster than caravans, carry much more cargo, and pay no tolls en route, so they are greatly undercutting the caravan trade. This new circumcontinental route is the big disruption to the geopolitical order which has triggered the Merchants' War.

## Cities of the Coast

### Huandun

Major city to the east of the playing area of this game, stable during this period and therefore not in play, ruled by a wily and competent tyrranos in middle years who is not under threat. Feudal state, self sufficient in most produce, importing luxuries only. Home city of the Red Company, an elite and feared mercenary unit. Total population including hinterlands, around 100,000.

Built on a rocky island in the Koan river, with the Tyrranos' fortress at the (high) south end. The lower north end of the island is not built up. From the north end of the island there are bridges to both banks.

Was an important port city, with a quay along most of the west side of the island, but the harbour is not deep enough for the new ocean-going ships, so its strategic importance is waning. It is still the main terminus of the caravan road.

#### Architecture

Having had major fires in the past, the city has laws requiring all buildings to be built in stone, although wooden floors and roof structures are permitted. Roofs are clad in slate-like tiles of a pale high-quality limestone from a nearby quarry. Because space is at a premium, buildings are tall and crowded together, with mainly narrow streets; somewhat like Edinburgh's old town.

#### Economy

The city has historically been home to merchants trading with the north by caravan, and they're still present, but the trade is taking a bad hit as a result of the development of the great ships. It has a reputation for fine craftsmanship in non-ferrous metals &mdash; a trade in goblets, small mechanical devices, belt and harness buckles, and other things of that type, often of high quality.

There is also a very significant slave market here.

However, its main business is as a centre for mercenary companies.

#### Mercenary Companies

##### Red Company

The rising mercenary company, already the most powerful (but a long way yet from the peak of its power). Revolutionarily, it is, in our terms, a worker's co-op, with elected officers. At this time, exclusively a heavy infantry unit. Lead contractor for Fannish and for Gortanien (which is to say, actually for Nikkei) in the Merchants' War.

##### Dragon Company

A conventional mercenary company, on the losing side of the last Koantuan siege; weak. Heavy infantry, some cavalry. Not engaged in the Merchants' War; doing city defence in Koantuan.

##### Rothic's Company

Small heavy infantry company, subcontractor to Red Company in the Merchants' War, will be assigned to garrison Tchahua when it is taken.

##### Wolf Company

A light cavalry company, essentially, specialists in scouting and skirmishing; but subcontractors to Red Company left behind as garrison in Hans'hua after Red Company move on join Gortanien on the Andale campaign. This is the company to which Choiremheadh initially belongs.

### Koantuan

Former the major city, upstream on the same river (Koan) as Huandun, river is navigable by barge between the two cities. Still the largest city in the littoral, but impoverished and partly ruinous after sieges and sacks. Very much under the influence of Huandun and probably pays tribute but may not be formally conquered. One branch of the caravan road leads here, although caravans arriving at Koantuan now tend to use it only as a stopover before going downstream to Huandun. The city has traditionally been ruled by a tyrranos, but there are no current candidates and the city is being administered by an ad-hoc committee of influential citizens.

Total population including hinterlands, around 50,000.

#### Economy

Pretty much a mess. After two sieges, the mercantile trade has pretty much all moved to Huandun; the city levies taxes on residents of the city and on estates in its vicinity, but it doesn't have effective power to collect those taxes. There's a lot of crime.

### Sinhua

Sinhua is the other southern end of the caravan road, and its primary strategic wealth is from the market. However, years of civil war, and the fact that Sinhua's port does not accommodate the new larger ships, has led to caravans going instead to either Koantuan or Hanshua. Sinhua also produces agricultural produce, wine and textiles for export, but this trade has been disrupted and unless urgently rebuilt will not provide much taxation income. Total population including hinterlands, around 50,000.

#### Mercenary companies

##### Swift Company

Took a bit of a mauling in the Sinhua civil war, where they fought for the losing side; in the Merchants' War they're subcontractors to Red Company, but neither trusted nor well thought of. They're left in Tchahua as the bulk of the garrison, but under Rothic's overall command.

##### Tiger Company

I don't know. Canonically they exist. They may be garrisoning Sinhua on behalf of Fannish.

### Tchahua

Port city, formerly unimportant, but has deep, well protected harbour favoured by new, larger ships. Potential new south end of the caravan road, also the only port south of Anmouth and west of Huandun that the new ships can use. Exports grain, textiles and wine. At the beginning of play Tchahua is utterly trashed and will require extensive rebuilding, but its strategic situation is still good. Total population including hinterlands, around 30,000.

### Quanhua, other minor cities

There are several other 'cities of the coast', none as significant as either Huandun or Sinhua. Quanhua has a border with Huandun and is probably actually to the east of it, between it and the Great Place. But there might be four or five other minor league cities between Huandun and Sinhua. Invent as/if needed. Quanhua is stable during this period, and not in play.

##### Quanjun

Quanjun is not a city; it's a series of partially man-made caves under the very edge of the high plateau, right at the head of the Quan valley, in a region where large dragons are particularly active; and it's the site of a major dragon cult festival held every eight years. Between festivals, there's a very small garrison and a few caretakers in residence. During festivals, most of the richest and most influential people of the whole game area will be there whether or not they're actually dragon cult true believers, together with their servants, entertainers, bodyguards, and hangers on &mdash; so, it's an extremely busy place.

About half a day's ride south from Quanjun is the temple-fortress of the Brethren of the High Dragon, who are an order of military priests mainly drawn from among the aristons, which is not long past the peak of its power.

#### Hans'hua

Not really a 'city of the coast', because it's up on the plateau, but of the same culture. Draws its income from the Caravan Road. Has total control of the Caravan Road, so this is still lucrative, but is becoming less lucrative as more traffic goes by sea. Could improve trade on the Caravan Road by improving security over the steppe, which would mean rebuilding some ruinous, abandoned fort/caravanserrai complexes, and could actually afford to do this. Exports nothing, imports everything it needs to survive, including livestock, grain and even most vegetables, although it controls some limited farmland and heavily managed forestry both on the extreme southern margin of the steppe, and on its southern border where it holds a small amount of fertile land in complex hill country in a disputed border area where it adjoins lands of Huandun, Sinhua and Tchahua.

Hans'hua must have friendly relations with at least one of Huandun, Sinhua, Tchahua or the An in order to be able to import food. Total population including hinterlands, around 8,000.

## Western Clans

Western clans are generally dark-skinned people; they're related to the common people (not the ariston class) of the cities of the coast.

### Gor

No city; no significant ports; no major stronghold; mainly small distributed agrarian settlements. Southwesternmost and most numerous of the western clans, the Gor are self sufficient in most things but threatened by the cities of the coast (primarily Sinhua, Tchahua) on their east. Subsidised by the An in order to maintain their eastern defences. Total population around 100,000.

The Gor border is fortified and maintained along its length, whatever happens in the Merchants' War, and forms the western edge of the playable area.

### An

No city; one significant port; two major strongholds (Silverhold and Dawnhold); mainly small distributed agrarian and forest settlements. Second most significant of the western clans, undefended border with Gor on the south, otherwise well defended by high mountains. Generally self sufficient, and, additionally, in possession of the world's only highly significant silver mine. Annual market on steppe under Dawnhold. Total population around 70,000.

### Dor, Ku

Less significant western clans, with land to the north of the An. Self sufficient. Outside the game area. No plot involvement.

## Steppe Tribes

#### Coiremhiconicfhearchaorusduadh ('Corrymicnic')

Chaotic hero-culture steppe nomads, fairly numerous, widely feared, live off herds and raiding, not very organised, incapable of sustaining an attack over a large area or long period. Threat to caravans approaching Hans'hua territory to the north; threat to the An and major threat to the Wild Herd. Total population around 70,000. 

#### Rhiconicfhearchaorusduadh ('Ricnic')

More organised hero culture steppe nomads, to the east and north. Live off herds and raiding, but really too far away to have much impact on the story. Total population around 30,000.

#### Wild Herd

Reclusive horse-breeding female-centric tribe, very unusual customs and language, significantly different ethnic type, normally naked; widely seen as not really human. Exceptional riders and archers, defend effectively but are not aggressive. Live in swamps where rivers that drain the steppe go underground on the southern edge of the steppe. Rarely seen, except at the annual Dawnhold fair, where they sell geldings, both horses and men. Total population around 5,000. The player probably won't meet them (except possibly as slaves) apart from Coiremheadh, who will be a character.

### Cities of the North

Are far away at the other end of the caravan road, and semi-legendary. Merchants and caravan drivers go there, but as far as other people are concerned they are off the map, of no strategic consequence. Export steel tools and weapons, furs, woollen textiles. Import fine textiles, wine, grain, precious metals, luxuries.

### The Great Place

To the east, beyond the Rim, which is impassable from the littoral. Out of play. See MGI.

## Factions

None of these named leaders are playable roles, but all of them are characters the player can interact with, and perhaps side with. Apart from Kildor, who won't be around for long enough.

### Sinhua (Kildor)

Kildor, tyrranos of Sinhua, is killed by Xinta at the very beginning of the narrative, and his sons are killed by Falloch. That can't be changed. Any survivors supporters of Kildor are unlikely to support any of the factions in the plot.

### Sinhua (Fannish)

The Fannish regime takes over from Kildor. The treasury is empty, and Fannish does not have either popular support or loyal troops to secure his rule, so he must employ mercenaries. In order to employ mercenaries to secure his own state, he needs to sieze wealth from other states, so he essentially deficit funds the invasion of Tchahua, siezing enough wealth from Tchahua to fund the invasion of Hans'hua. Hans'hua, if captured, provides enough booty to pay off the debt and enough ongoing income so long as it remains under Sinhua's control to continue to pay for a mercenary garrison in Sinhua. However if Sinhua loses Hans'hua, Fannish's position is very weak indeed.

### Sinhua (Xinta)

If Xinta succeeds in deposing Fannish she can establish a successful regime in Sinhua. But she doesn't have popular support or loyal troops either (unless she has some means of recruiting these) so will have to continue to hire a mercenary garrison. If she allies with Hans'hua and/or Tchahua she can probably tap them for some subsidy to prevent a new outbreak of disorder and war.

### Sinhua (Tiger Company)

I don't know who the captain general of Tiger Company is at this point, but as the better of the Sinhua mercenary companies at a time when the ariston families of the city have been decimated by civil war, he's the person with the best chance of taking over if Fannish is killed.

### Tchahua (Selchae)

Selchae is daughter of the deposed tyrranos of Tchahua; but more importantly is descendant in the female line from the Seal Princesses who ruled the settlement before the invasion of the aristons, and is thus the hereditary priestess of the seal cult, which is the religion of common people of the city.

She is captured in the Sinhua invasion and is held hostage with other elite young women in the Residence, held by Rothic as castellan on behalf of Fannish of Sinhua. How she gets out of that mess is going to be tricky, but she does have a claim to rule which would be supported by most of the common people.

### Tchahua (Selachen)

Selachen, son and eldest child of the tyrranos of Tchahua, flees the Sinhua invasion and at the opening of the game is with the resistance hiding out in forests. He could potentially be reinstated if Dalwhiel allies with him. He's likely to resist the installation of Rothic as tyrranos, but how much support he has I'm not certain. 

### Tchahua (Rothic)

Rothic is castellan in possession of the Residence in Tchahua at the beginning of play, with thirty-one fairly loyal, fairly disciplined feudal levies. He's in nominal control of another 200 Tiger Company mercenaries who nominally garrison the city, but they're unpaid, drunk, and out of control. He cannot re-establish Tchahua as an independent city unless he can bring the mercenaries under control, or defeat them. Rothic has no possible legitimacy as tyrranos unless he marries Selchae, and would also have to maintain a garrison and/or rapidly build up loyalty within the city.

### Tchahua (Dalwhiel)

It's possible that Dalwhiel could seek to set himself up as tyrranos of Tchahua. He has more legitimacy than Rothic, as he is a native and could easily present himself as saviour of the city. However, he has no legitimacy unless he marries Selchae, and without the castle he can't hold the city (or protect the ship, and unless he can protect the ship Karakhan won't stay so there is no crew so he has no fighting force), so he would need to either become friendly with Rothic and then assassinate him, or else mount a commando raid on the castle. I think, in any case, it's more interesting if he does what he does in Merchant &mdash; namely, tries to set up a democracy.

### Hans'hua (council of oligarchs)

Council of Oligarchs won't retain control unless they reach a deal with the An, and since that closes off most of the plot lines I've thought of so far I probably won't allow that to happen. Otherwise, all except the one who sells the gate are hung when Sinhua seize control. What remains of the city guard after Sinhua seize control are probably absorbed into the mercenary companies.

### Hans'hua (Falloch)

Falloch rules Hans'hua as a loyal vassal of his brother Fannish. If some other faction managed to depose Fannish before Falloch is himself killed he would try to form an alliance against whoever took over in Sinhua, but as long as he's in control in Hans'hua he administers fairly competently, working to build up the caravan trade and consequently the profits from the tolls on it. Falloch is an imposed outsider and is unlikely to have much popular support, so is even more reliant on mercenaries than other Hans'hua regimes.

### Hans'hua (Goratin)

If Falloch is killed by Xinta, Goratin (if still alive &mdash; or a senior Hans'hua merchant if we treat it as canon that all the oligarchs have been killed) takes over as governor of Hans'hua but would quickly seek to set himself as an independent tyrranos &mdash; which he could do, fairly simply, by simply ceasing to pay tribute to Sinhua. Goratin's strategic interest is then to establish friendly relations with at least one of the An, Huandun, or Tchahua, in order to have a reliable source of food. He would also be interested in a change of regime in Sinhua so a Goratin/Xinta alliance to install Xinta as tyrranos in Sinhua is possible (but then again he might have his own preferred candidate).

### Hans'hua (Karae)

If the game starts before the beginning of the Merchant's war (as I intend it to), then it's plausible (but unlikely) that the player could get to Hans'hua before RedCo, which means that the player won't meet Karae before she's injured. Therefore it's probably canon that she does become slave to Andarogan, and does leave for Andale when he does.

However the Andale campaign goes, Karae probably returns from Andale without Andarogan, but her knowledge of the pump system means that she can capture Hans'hua with a very small force indeed.

If Karae succeeds in taking Hans'hua her interests would be in achieving a stable administration, expanding caravan traffic and supporting the friends she's made along the way. She may be able to recruit a new city guard from among the Western Tribes, but if not she can afford to employ mercenaries. Alliances with An, Gor, Tchahua and Sinhua (Xinta) are all possible.
